==> spip_3.2.11.orig.tar.xz: plugins-dist/mots/lang/mots_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Önemli grup :</b> bu grupta anahtar sözcük seçmeniz şiddetle önerilir.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'site yöneticileri',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'yazarlar',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'foruma ileti gönderirken kamusal site ziyaretçileri.',

	// I
	'icone_creation_groupe_mots' => 'Yeni bir sözcük grubu oluştur',
	'icone_creation_mots_cles' => 'Yeni bir anahtar sözcük oluştur',
	'icone_modif_groupe_mots' => 'Bu sözcük gurubunu değiştir',
	'icone_modifier_mot' => 'Bu anahtar sözcüğü değiştir',
	'icone_mots_cles' => 'Anahtar sözcükler',
	'icone_supprimer_groupe_mots' => 'Bu grubu sil',
	'icone_voir_tous_mots_cles' => 'Tüm anahtar sözcükleri göster',
	'info_articles_lies_mot' => 'Bu anahtar sözcüğe bağlı makaleler',
	'info_changer_nom_groupe' => 'Bu gurubun adını değiştir :',
	'info_creation_mots_cles' => 'Burada sitenin anahtar sözcüklerini yaratınız ve konfigürasyonunu yapınız.',
	'info_dans_groupe' => 'Grupta :',
	'info_delet_mots_cles' => '<b>@titre_mot@</b>(@type_mot@) anahtar sözcüğünü silmek istediniz. Bu anahtar sözcük  
<b>@texte_lie@<b>’e bağlı olduğundan, bu kararı onaylamanız gerekiyor :', # MODIF
	'info_groupe_important' => 'Önemli gurup',
	'info_modifier_mot' => 'Anahtar sözcüğü değiştir :',
	'info_mots_cles' => 'Anahtar sözcükler',
	'info_mots_cles_association' => 'Bu grubun anahtar sözcüklerinin bağlanabilir :',
	'info_oui_suppression_mot_cle' => 'Bu anahtar sözcüğü temelli silmek istiyorum',
	'info_question_mots_cles' => 'Sitenizde anahtar sözcük kullanmak istiyor musunuz ?',
	'info_qui_attribue_mot_cle' => 'Bu guruptaki anahtar sözcüklerin kim tarafından verilebileceği :',
	'info_retirer_mot' => 'Bu anahtar sözcüğü geri al',
	'info_retirer_mots' => 'Tüm anahtar sözcükleri geri al',
	'info_rubriques_liees_mot' => 'Bu anahtar sözcüğe bağlı bölümler',
	'info_selection_un_seul_mot_cle' => 'Bu grupta bir defada sadece bir anahtar sözcük seçebilirsiniz.', # MODIF
	'info_supprimer_mot' => 'Bu sözcüğü sil',
	'info_titre_mot_cle' => 'Anahtar sözcüğün ismi veya başlığı',
	'info_un_mot' => 'Her defasında tek bir anahtar sözcük',
	'item_ajout_mots_cles' => 'Forumlara anahtar sözcük eklemeye izin ver',
	'item_non_ajout_mots_cles' => 'Forumlarda anahtar sözcük kullanımını yasakla',
	'item_non_utiliser_config_groupe_mots_cles' => 'Anahtar sözcük guruplarının gelişmiş konfigürasyonunu kullanma',
	'item_non_utiliser_mots_cles' => 'Anahtar sözcükleri kullanma',
	'item_utiliser_config_groupe_mots_cles' => 'Anahtar sözcük guruplarının gelişmiş konfigürasyonunu kullan',
	'item_utiliser_mots_cles' => 'Anahtar sözcükleri kullan',

	// L
	'logo_mot_cle' => 'ANAHTAR SÖZCÜK LOGOSU',

	// T
	'texte_config_groupe_mots_cles' => 'Örneğin, grup başına tek sözcük seçme olanağı bulunduğunu,
           bir grubun önemli olduğunu ... belirtmek gibi,
           anahtar sözcüklerin gelişmiş konfigürasyonunu çalıştırmak ister misiniz ? ', # MODIF
	'texte_mots_cles' => 'Anahtar sözcükler makaleleriniz arasında bölümlerdeki yerlerini gözetmeksizin konusal bağlantılar kurmaya yarar.  Böylece, sitenizdeki gezintiyi zenginleştirir, şablonlarınızda makalelerin sunumunu kişiselleştirmek için bu özellikleri kullanabilirsiniz.',
	'texte_mots_cles_dans_forum' => 'Kamu sitesinin forumlarında, ziyaretçiler tarafından seçilebilir anahtar sözcüklerin kullanımına izin vermek istiyor musunuz ?  (Dikkat : bu seçeneğin kullanımı karmaşıktır).',
	'texte_nouveau_mot' => 'Yeni sözcük',
	'titre_config_groupe_mots_cles' => 'Anahtar sözcük guruplarının konfigürasyonu',
	'titre_gauche_mots_edit' => 'ANAHTAR SÖZCÜK NO:',
	'titre_mots_cles_dans_forum' => 'Kamu sitesi forumlarında anahtar sözcükler ',
	'titre_mots_tous' => 'Anahtar sözcükler',
	'titre_nouveau_groupe' => 'Yeni grup',
	'titre_page_mots_tous' => 'Anahtar sözcükler'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=tr
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Önemli grup :</b> bu grupta anahtar sözcük seçmeniz şiddetle önerilir.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'site yöneticileri',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'yazarlar',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'foruma ileti gönderirken kamusal site ziyaretçileri.',

	// I
	'icone_creation_groupe_mots' => 'Yeni bir sözcük grubu oluştur',
	'icone_creation_mots_cles' => 'Yeni bir anahtar sözcük oluştur',
	'icone_modif_groupe_mots' => 'Bu sözcük gurubunu değiştir',
	'icone_modifier_mot' => 'Bu anahtar sözcüğü değiştir',
	'icone_mots_cles' => 'Anahtar sözcükler',
	'icone_supprimer_groupe_mots' => 'Bu grubu sil',
	'icone_voir_tous_mots_cles' => 'Tüm anahtar sözcükleri göster',
	'info_articles_lies_mot' => 'Bu anahtar sözcüğe bağlı makaleler',
	'info_changer_nom_groupe' => 'Bu gurubun adını değiştir :',
	'info_creation_mots_cles' => 'Burada sitenin anahtar sözcüklerini yaratınız ve konfigürasyonunu yapınız.',
	'info_dans_groupe' => 'Grupta :',
	'info_delet_mots_cles' => '<b>@titre_mot@</b>(@type_mot@) anahtar sözcüğünü silmek istediniz. Bu anahtar sözcük  
<b>@texte_lie@<b>’e bağlı olduğundan, bu kararı onaylamanız gerekiyor :', # MODIF
	'info_groupe_important' => 'Önemli gurup',
	'info_modifier_mot' => 'Anahtar sözcüğü değiştir :',
	'info_mots_cles' => 'Anahtar sözcükler',
	'info_mots_cles_association' => 'Bu grubun anahtar sözcüklerinin bağlanabilir :',
	'info_oui_suppression_mot_cle' => 'Bu anahtar sözcüğü temelli silmek istiyorum',
	'info_question_mots_cles' => 'Sitenizde anahtar sözcük kullanmak istiyor musunuz ?',
	'info_qui_attribue_mot_cle' => 'Bu guruptaki anahtar sözcüklerin kim tarafından verilebileceği :',
	'info_retirer_mot' => 'Bu anahtar sözcüğü geri al',
	'info_retirer_mots' => 'Tüm anahtar sözcükleri geri al',
	'info_rubriques_liees_mot' => 'Bu anahtar sözcüğe bağlı bölümler',
	'info_selection_un_seul_mot_cle' => 'Bu grupta bir defada sadece bir anahtar sözcük seçebilirsiniz.', # MODIF
	'info_supprimer_mot' => 'Bu sözcüğü sil',
	'info_titre_mot_cle' => 'Anahtar sözcüğün ismi veya başlığı',
	'info_un_mot' => 'Her defasında tek bir anahtar sözcük',
	'item_ajout_mots_cles' => 'Forumlara anahtar sözcük eklemeye izin ver',
	'item_non_ajout_mots_cles' => 'Forumlarda anahtar sözcük kullanımını yasakla',
	'item_non_utiliser_config_groupe_mots_cles' => 'Anahtar sözcük guruplarının gelişmiş konfigürasyonunu kullanma',
	'item_non_utiliser_mots_cles' => 'Anahtar sözcükleri kullanma',
	'item_utiliser_config_groupe_mots_cles' => 'Anahtar sözcük guruplarının gelişmiş konfigürasyonunu kullan',
	'item_utiliser_mots_cles' => 'Anahtar sözcükleri kullan',

	// L
	'logo_mot_cle' => 'ANAHTAR SÖZCÜK LOGOSU',

	// T
	'texte_config_groupe_mots_cles' => 'Örneğin, grup başına tek sözcük seçme olanağı bulunduğunu,
           bir grubun önemli olduğunu ... belirtmek gibi,
           anahtar sözcüklerin gelişmiş konfigürasyonunu çalıştırmak ister misiniz ? ', # MODIF
	'texte_mots_cles' => 'Anahtar sözcükler makaleleriniz arasında bölümlerdeki yerlerini gözetmeksizin konusal bağlantılar kurmaya yarar.  Böylece, sitenizdeki gezintiyi zenginleştirir, şablonlarınızda makalelerin sunumunu kişiselleştirmek için bu özellikleri kullanabilirsiniz.',
	'texte_mots_cles_dans_forum' => 'Kamu sitesinin forumlarında, ziyaretçiler tarafından seçilebilir anahtar sözcüklerin kullanımına izin vermek istiyor musunuz ?  (Dikkat : bu seçeneğin kullanımı karmaşıktır).',
	'texte_nouveau_mot' => 'Yeni sözcük',
	'titre_config_groupe_mots_cles' => 'Anahtar sözcük guruplarının konfigürasyonu',
	'titre_gauche_mots_edit' => 'ANAHTAR SÖZCÜK NO:',
	'titre_mots_cles_dans_forum' => 'Kamu sitesi forumlarında anahtar sözcükler ',
	'titre_mots_tous' => 'Anahtar sözcükler',
	'titre_nouveau_groupe' => 'Yeni grup',
	'titre_page_mots_tous' => 'Anahtar sözcükler',
];
